If a token should be ignored, the column is set to TRUE,
otherwise to FALSE.
add_stylerignore(pd_flat)A parse table.
A token is ignored iff one of the two conditions hold:
it falls between a start and a stop marker whereas the markers are on
their own line. Which tokens are recognized as markers is controlled with
the R options styler.ignore_start and styler.ignore_stop.
it is not a comment, but the last token on the line is a marker.
See examples in stylerignore.